pub enum ConfigError {
ReadError {
path: PathBuf,
source: Error,
},
ParseError(Error),
UserSectionInCommitted {
path: PathBuf,
},
SchemaVersionMismatch {
config_version: String,
compiled_version: &'static str,
},
ThresholdOutOfRange {
value: f32,
},
InvalidEnvVar {
var: &'static str,
raw: String,
reason: &'static str,
},
UnknownSeverity {
rule: String,
value: String,
},
}Variants
ReadError
ParseError(Error)
UserSectionInCommitted
.marque.toml contains a [user] section (FR-010, SC-006).
SchemaVersionMismatch
Schema version in config doesn’t match compiled schema.
ThresholdOutOfRange
Confidence threshold out of range.
InvalidEnvVar
Environment variable could not be parsed into the expected type.
UnknownSeverity
Rule severity string in config is not one of the recognized values.
Implementations